%———————————————————————————————————————————
%————————————————— JOURNAL —————————————————————
%—————————————————— OF ———————————————————————
%————————————————  HISTORICAL  ————————————————————
%—————————————————  SYNTAX  —————————————————————
%———————————————————————————————————————————
%———————————————————————————————————————————
%———————————————— Style File ——————————————————————
%———————————————————————————————————————————

% This Class File is based on the wonderful work done by
% Kai von Fintel, Christopher Potts, and Chung-chieh Shan
% fixed up by Moreno Mitrovic in 2011-12,
% fiddled with by George Walkden in 2018-12,
% updated for LuaLaTeX and XeLaTeX by Vítek Novotný in 2020-07,
% merged with jhs_submission.cls by Vítek Novotný in 2020-11

\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{jhs}[2020/11/01 v.2.0 Class for Journal of Historical Syntax]

% OUTLINE OF THIS CLASS FILE
%   option declarations 
%   required packages 
%   metadata 
%   page dimensions 
%   title 
%   running headers 
%   frontmatter 
%   sectioning 
%   footnotes 
%   bibliography 
%   backmatter 
%   other environments 
%   useful macros




%=====================================================================
%======================== option declarations ========================

\newif\if@final\@finalfalse


\DeclareOption*{\PassOptionsToClass{final}{article}}




\DeclareOption{10pt}{\@sizeoption@err}
\DeclareOption{11pt}{\@sizeoption@err}

\DeclareOption{final}{\@finaltrue}


\ProcessOptions\relax
\LoadClass[11pt,twoside]{article}

\linespread{1.05} 


%=====================================================================
%========================= required packages =========================

\RequirePackage{ifxetex,ifluatex,ifpdf}
\newif\ifxetexorluatex
\ifxetex
  \xetexorluatextrue
\else
  \ifluatex
    \xetexorluatextrue
  \else
    \xetexorluatexfalse
  \fi
\fi
\newif\ifdvi
\ifpdf
  \dvifalse
\else
  \ifxetexorluatex
    \dvifalse
  \else
    \dvitrue
  \fi
\fi
\ifxetexorluatex\else
  \RequirePackage[utf8]{inputenc}
\fi
\RequirePackage[leqno,tbtags]{amsmath}
\ifxetexorluatex
  \RequirePackage{fontspec}
  \RequirePackage{unicode-math}
  \setmainfont[Ligatures=TeX]{TeX Gyre Pagella}
  \setmathfont[math-style=ISO,bold-style=ISO]{texgyrepagella-math.otf}
\else
  \RequirePackage[T1]{fontenc}
  \RequirePackage[sc]{mathpazo}
  \RequirePackage{tgpagella}
\fi
\RequirePackage{xspace}
\RequirePackage{etoolbox}
% microtype handles punctuation at the right margin. We want it for
% the final product, but it's okay if authors lack it.
\IfFileExists{microtype.sty}{%
  \RequirePackage[final,protrusion={true,compatibility}]{microtype}
}{}
\RequirePackage{ifthen}
\RequirePackage[longnamesfirst]{natbib}
\RequirePackage[usenames]{color}
\definecolor{jhslinkcolor}{rgb}{.2,.2,.7}
\RequirePackage[colorlinks,breaklinks,
                linkcolor=jhslinkcolor, 
                urlcolor=jhslinkcolor, 
                citecolor=jhslinkcolor,
                filecolor=jhslinkcolor,
                plainpages=false,
                pdfpagelabels,
                bookmarks=false,
                pdfstartview=FitH]{hyperref}
\RequirePackage{doi}
\urlstyle{rm}
% If the author is using postscript (discouraged), then load the
% breakurl package, else don't load it.
\ifdvi
  \RequirePackage{breakurl}
\fi
\RequirePackage{graphicx}
\RequirePackage{float}
\RequirePackage[hang,FIGBOTCAP,loose]{subfigure}
%\RequirePackage{lastpage}

%=====================================================================
%============================= metadata ==============================

\def\@pdfauthor{\relax}
\newcommand{\pdfauthor}[1]{\gdef\@pdfauthor{#1}}
\def\@pdftitle{\relax}
\newcommand{\pdftitle}[1]{\gdef\@pdftitle{#1}}
\def\@pdfkeywords{\relax}
\newcommand{\pdfkeywords}[1]{\gdef\@pdfkeywords{#1}}

\hypersetup{pdfauthor=\@pdfauthor, 
            pdftitle=\@pdftitle,
            pdfkeywords=\@pdfkeywords}

\def\@jhsvolume{\relax}
\newcommand{\jhsvolume}[1]{\gdef\@jhsvolume{#1}}

\def\@jhsarticle{\relax}
\newcommand{\jhsarticle}[1]{\gdef\@jhsarticle{#1}}

\def\@jhsyear{\relax}
\newcommand{\jhsyear}[1]{\gdef\@jhsyear{#1}}


\def\@jhslastpage{\relax}
\newcommand{\jhslastpage}[1]{\gdef\@jhslastpage{#1}}
            
%=====================================================================
%========================== page dimensions ==========================

% Vertical.
\paperheight=11in
\topmargin=0in     %
\headheight=0.2in  % head: 1.5in (margin + head + sep = .5; latex adds 1in)
\headsep=0.3in     %
\topskip=0.1in     % included in the textheight
\textheight=8in    % text is 8in
\footskip=0.5in    % foot: 1.5in (.5 + 1.0in leftover)
\parskip=0pt

% Horizontal.
\paperwidth=8.5in
\textwidth=5.1in
\oddsidemargin=0.5in  % 1.5in due to LaTeX's calculations
\evensidemargin=0.5in % 1.5in due to LaTeX's calculations
\raggedbottom % constant spacing in the text; cost is a ragged bottom
\parindent=0.25in
\leftmargini=0.5in
\@ifundefined{mathindent}{}{\mathindent=0.5in\relax}%

% Tell dvips about our paper.
\special{papersize=8.5in,11in}

%=====================================================================
%============================== title ================================

\usepackage{soul}
% Formats individual <name--institute> pairs inside \author.
\newcommand{\jhsauthor}[1]%
{\begin{minipage}[t]{17pc}\centering
        #1%
 \end{minipage}\hspace{.5pc plus 1pc}%
 \ignorespaces
}

\renewcommand*{\title}[2][]{\gdef\@shorttitle{#1}\gdef\@title{#2}}
\renewcommand*{\author}[2][]{\gdef\@shortauthor{#1}\gdef\@author{#2}}



% Adapted from JMLR.
\renewcommand{\maketitle}{%
  \par
  \begingroup
  \renewcommand{\thefootnote}{\fnsymbol{footnote}}
  \@maketitle\@thanks
  \setcounter{footnote}{0}
  \endgroup
  \let\maketitle\relax \let\@maketitle\relax
  \gdef\@thanks{}
  \let\thanks\relax%
}

% From salt.cls.
\newskip\onelineskip 
\onelineskip=\baselineskip 
\advance\onelineskip by0pt plus 4pt minus 2pt

\def\@maketitle{%
  \vbox{\hsize\textwidth%
    \linewidth\hsize%
    \centering
    \vskip\onelineskip
        \vspace{.25in}
    			\hrule
    \vspace{.25in}
    \Large{\@title}\@@par
    \vspace{.25in}
    			\hrule
    \vspace{.25in}

    \normalsize
    \newcommand\institute[1]{\textit{\textit{##1}}}%
    \newcommand{\AND}{\ignorespaces}%
    \let\par\@empty
    \sc\@author
    \lineskiplimit\onelineskip
    \lineskip\onelineskip
    \@@par
  }%
  \global\everypar{\everypar{}\vskip 3.5ex}
}

%=====================================================================
%========================== running headers ==========================

% Creative commons license text.  The font is even smaller here than
% it is elsewhere in the headers so that we have a chance of fitting
% the whole license on the page.
\if@final
  \newcommand{\cctext}{{\footnotesize This is an open-access article
    distributed under the terms of a Creative Commons License
    (\http{creativecommons.org/licenses/by/4.0}).}}
\else
  \newcommand{\cctext}{{\footnotesize This manuscript is submitted
    for consideration.}}
\fi

% This boolean switch lets the user control whether the logo is
% included even when the requisite image file is present.  (If it is
% missing, then the class file accommodates that no matter how the
% switch is set.)
\newboolean{logo}
\setboolean{logo}{true} % Default true (include logo if it's present)
\newcommand{\jhslogo}{\setboolean{logo}{true}}
\newcommand{\nojhslogo}{\setboolean{logo}{false}}

% This sets the font size for the header and footer on all pages.
\newcommand{\headerfontsize}{\footnotesize}

\def\today{\ifcase\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space\textup{\number\day, \number\year}}

% Prints publication and copyright info on the first page
\gdef\@articlenumber{}%
\newcommand{\firstpageheadings}%
{
  \def\ps@spfirstheadings{%
    \let\@mkboth\@gobbletwo%
    \renewcommand{\@oddhead}{%
      \headerfontsize%
      % If the switch is set to "include image",
      \ifthenelse{\boolean{logo}}{%
        \ifdvi
          % If the ps logo is present,
          \IfFileExists{jhs-logo.ps}{%   
            % then insert the postscript version,
            \begin{minipage}[c]{.35in}
              \includegraphics[width=.35in]{jhs-logo}
            \end{minipage}%
          }{}% else, nothing; closes \IfFileExists
        \else
          % If the pdf logo is present,
          \IfFileExists{jhs-logo.pdf}{%
            % then insert the pdf version,
            \begin{minipage}[c]{.35in}
              \includegraphics[width=.35in]{jhs-logo}
            \end{minipage}%
          }{}% else nothing; closes \IfFileExists
        \fi % close \ifdvi
      }{}% closes \ifthenelse
      \begin{minipage}[c]{5.35in}
        \textsc{\so{submission for publication}}\\
        \href{http://historicalsyntax.org}{\so{\textsc{Journal}} \textit{of} \so{\textsc{Historical Syntax}}} \\
        \textsc{pre-review --- submitted version as of \today}
      \end{minipage}%
    }%
    \renewcommand{\@oddfoot}{%
      \begin{minipage}[c]{1\textwidth}%
        \footnotesize\copyright \@jhsyear\ \@shortauthor\\
        \cctext
      \end{minipage}%
    }%
    \renewcommand{\@evenhead}{}%
    \renewcommand{\@evenfoot}{}%
  }%
  \thispagestyle{spfirstheadings}%
}%

\newcommand{\firstpagefinalheadings}%
{
  \def\ps@spfirstheadings{%
    \let\@mkboth\@gobbletwo%
    \renewcommand{\@oddhead}{%
      \headerfontsize%
      % If the switch is set to "include image",
      \ifthenelse{\boolean{logo}}{%
        \ifdvi
          % If the ps logo is present,
          \IfFileExists{jhs-logo.ps}{%   
            % then insert the postscript version,
            \begin{minipage}[c]{.35in}
              \includegraphics[width=.35in]{jhs-logo}
            \end{minipage}%
          }{}% else, nothing; closes \IfFileExists
        \else
          % If the pdf logo is present,
          \IfFileExists{jhs-logo.pdf}{%
            % then insert the pdf version,
            \begin{minipage}[c]{.35in}
              \includegraphics[width=.35in]{jhs-logo}
            \end{minipage}%
          }{}% else nothing; closes \IfFileExists
        \fi % close \ifdvi
      }{}% closes \ifthenelse
      \begin{minipage}[c]{5.35in}
        \href{http://historicalsyntax.org}{\so{\textsc{Journal}} \textit{of} \so{\textsc{Historical Syntax}}} \\
        Volume \@jhsvolume, Article \@jhsarticle: 1--\@jhslastpage, \@jhsyear\\
      \end{minipage}%
      \gdef\@articlenumber{\@jhsarticle}
    }%
    \renewcommand{\@oddfoot}{%
      \begin{minipage}[c]{1\textwidth}%
        \footnotesize\copyright \@jhsyear\ \@shortauthor\\
        \cctext
      \end{minipage}%
    }%
    \renewcommand{\@evenhead}{}%
    \renewcommand{\@evenfoot}{}%
  }%
  \thispagestyle{spfirstheadings}%
}%




% Prints abbreviated article information on non-initial pages.
\def\ps@spheadings{%
  \let\@mkboth\@gobbletwo%
  \def\@oddhead{{\headerfontsize \@shorttitle}\hfill}% short title, inner
  \def\@oddfoot{\hfill{\headerfontsize\thepage}\hfill}% centered pg no
  \def\@evenhead{\hfill{\headerfontsize\@shortauthor}}% author names, inner
  \def\@evenfoot{\hfill{\headerfontsize\thepage}\hfill}% centered pg no
}
\pagestyle{spheadings}  




%=====================================================================
%=========================== final typeset ===========================


\jhslogo
\if@final
\AtBeginDocument{\firstpagefinalheadings}
\else            
%\nojhslogo
\AtBeginDocument{\firstpageheadings}
\fi


%=====================================================================
%=========================== frontmatter =============================

% The spacing specs (arg 2 of \list) are the same for the mshistory,
% abstract, and keywords environments, except that the abstract is
% indented somewhat.

% Single parameter determines the left and right margin size.
\newcommand{\frontmatterspacing}[1]{%
  \small
  \topsep 10\p@ \@plus4\p@   \@minus6\p@ % from size12.clo
  \advance\topsep by3.5ex plus -1ex minus -.2ex
  \setlength{\listparindent}{0em}
  \setlength{\itemindent}{0em}
  \setlength{\leftmargin}{#1}
  \setlength{\rightmargin}{\leftmargin}
  \setlength{\parskip}{0em}
}

\newenvironment{mshistory}%
{\list{}{\frontmatterspacing{0em}}%
\item\relax}%
{\endlist}

\renewenvironment{abstract}%
{\list{}{\frontmatterspacing{0.25in}}%
\item\relax\textsc{\abstractname} }%
{\endlist}



%=====================================================================
%============================ sectioning =============================

    
\renewcommand{\section}{\@startsection{section}{1}{0pt}%
  {-3.5ex plus -1ex minus -.2ex}%
  {1.8ex plus.2ex}%
  {\noindent\large\normalfont\textsc}}

\renewcommand{\subsection}{\@startsection{subsection}{2}{0pt}%
  {-3.5ex plus -1ex minus -.2ex}%
  {1.8ex plus.2ex}%
  {\noindent\normalfont\it}}

\renewcommand{\subsubsection}{\@startsection{subsubsection}{3}{0pt}%
  {-3.5ex plus -1ex minus -.2ex}%
  {1.8ex plus.2ex}%
  {\noindent\normalfont\it}}


% General formatting --- for punctuating section headings.
\renewcommand{\@seccntformat}[1]{%
  \noexpand\expandafter\noexpand\ifstrequal\noexpand\expandafter{\noexpand\f@shape}{sc}{%
    \textup{\@nameuse{the#1}}%
  }{%
    \@nameuse{the#1}%
  }%
  \hspace{1em}%
}

%=====================================================================
%============================ footnotes ==============================

\renewcommand{\@makefntext}[1]{%
  \parindent=0.25in
  \noindent \hbox to \z@{\hss{\@thefnmark} \hfil}#1}

%=====================================================================
%=========================== bibliography ============================

\bibliographystyle{jhs}
\bibpunct[: ]{(}{)}{,}{a}{}{,}
\newcommand{\BIBand}{\&}
%\providecommand{\doi}[1]{\href{http://dx.doi.org/#1}{doi:#1}}  --- replaced by using doi.sty
\setlength{\bibsep}{0pt}
\setlength{\bibhang}{0.25in}

% In text citations
\newcommand{\posscitet}[1]{\citeauthor{#1}'s (\citeyear{#1})}
\newcommand{\possciteauthor}[1]{\citeauthor{#1}'s}
\newcommand{\pgposscitet}[2]{\citeauthor{#1}'s (\citeyear{#1}:~#2)}
\newcommand{\secposscitet}[2]{\citeauthor{#1}'s (\citeyear{#1}:~$\S$#2)}
\newcommand{\pgcitealt}[2]{\citealt{#1}:~#2}
\newcommand{\seccitealt}[2]{\citealt{#1}:~$\S$#2}
\newcommand{\pgcitep}[2]{(\citealt{#1}:~#2)}
\newcommand{\seccitep}[2]{(\citealt{#1}:~$\S$#2)}
\newcommand{\pgcitet}[2]{\citeauthor{#1} (\citeyear{#1}:~#2)}
\newcommand{\seccitet}[2]{\citeauthor{#1} (\citeyear{#1}:~$\S$#2)}

%=====================================================================
%============================ backmatter =============================

% Environment for formatting all the addresses.
\newenvironment{addresses}%
{\@@par
 \let\par\@empty
 \addvspace{3.25ex}%
 \noindent%\textbf{Author addresses}
 \small
 % Individual author addresses.
 \newenvironment{address}%
   {% For email addresses inside the address environment.
    %\newcommand{\email}{\texttt}%
    \begin{minipage}[t]{19pc}\raggedright}
   {\end{minipage}\hspace{.15pc plus1pc}}%
 \ignorespaces
}%
{\lineskiplimit 1pc
 \lineskip 1pc
 \@@par}

%=====================================================================
%======================== other environments =========================

% enumerate labeling that won't conflict with standard ex. numbers.
\renewcommand{\theenumi}{\roman{enumi}}
\renewcommand{\labelenumi}{\theenumi.}
\renewcommand{\theenumii}{\alph{enumii}}
\renewcommand{\labelenumii}{\theenumii.}

% list spacing ought to satisfy \itemsep + \parsep < \topsep + \parskip
\def\@listi{\leftmargin\leftmargini
            \parsep 4\p@  \@plus2\p@ \@minus\p@
            \topsep 10\p@ \@plus4\p@ \@minus\p@
            \itemsep4\p@  \@plus2\p@ \@minus\p@}
\let\@listI\@listi
\@listi

% typeset figures with lines above and below and the caption title and
% caption texts in boxes next to each other, top aligned.  these
% definitions extend those of float.sty.
%
% sp caption style
\newcommand\floatc@sp[2]{%
  \parbox[t]{0.15\textwidth}{{\@fs@cfont#1}}%
  \parbox[t]{0.85\textwidth}{#2}}%

% sp float style; uses the sp caption style
\newcommand\fs@sp{
  \def\@fs@cfont{\bfseries}\let\@fs@capt\floatc@sp
  \def\@fs@pre{\hrule\kern5pt}%
  \def\@fs@post{\kern5pt\hrule\relax}%
  \def\@fs@mid{\kern10pt}
  \let\@fs@iftopcapt\iffalse}

% users can override these commands using float.sty's functionality
\floatstyle{sp}
\restylefloat{figure}
\restylefloat{table}

%=====================================================================
%=========================== useful macros ===========================

\newcommand{\spj}{\emph{S\&P}\xspace}

\def\co{\colon\thinspace}

\DeclareRobustCommand\dash{%
  \unskip\nobreak\thinspace\textemdash\thinspace\ignorespaces}
\pdfstringdefDisableCommands{\renewcommand{\dash}{ - }}

% based on \url defined in hyperref.sty
\DeclareRobustCommand*{\http}{\hyper@normalise\http@}
\def\http@#1{\hyper@linkurl{\Hurl{#1}}{http://#1}}

\newcommand{\email}[1]{\href{mailto:#1}{#1}}

\providecommand{\sv}[1]{\ensuremath{\llbracket #1 \rrbracket}}

\usepackage{covington}

%================================ fin ================================
%=====================================================================
